@@ -28,7 +28,7 @@ asRGTimeVal(const GTimeVal *timeval)
 
 GString*
 asCGString(USER_OBJECT_ s_string) {
-    return(g_string_new(CHAR_DEREF(STRING_ELT(s_string, 0))));
+    return(g_string_new(asCString(s_string)));
 }
 
 GList*
@@ -41,8 +41,8 @@ toCGList(USER_OBJECT_ s_list, gboolean dup)
         SEXP s_element = VECTOR_ELT(s_list, i);
         gpointer element;
         if (IS_CHARACTER(s_element)) {
-            element = (gpointer)CHAR_DEREF(STRING_ELT(s_element, 0));
-            if (dup && element) element = g_strdup(element);
+          element = (gpointer)asCString(s_element);
+          if (dup && element) element = g_strdup(element);
         } else if (IS_INTEGER(s_element))
             element = GINT_TO_POINTER(INTEGER(s_element)[0]);
         else {
@@ -107,7 +107,7 @@ toCGSList(USER_OBJECT_ s_list, gboolean dup)
         SEXP s_element = VECTOR_ELT(s_list, i);
         gpointer element;
         if (IS_CHARACTER(s_element)) {
-            element = (gpointer)CHAR_DEREF(STRING_ELT(s_element, 0));
+            element = (gpointer)asCString(s_element);
             if (dup && element) element = g_strdup(element);
         } else if (IS_INTEGER(s_element))
             element = GINT_TO_POINTER(INTEGER(s_element)[0]);
